@@ -11,7 +11,7 @@ use File::Spec;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2023-06-30'; # DATE
 our $DIST = 'File-Symlink-Util'; # DIST
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 our @EXPORT_OK = qw(
                        symlink_rel
@@ -20,6 +20,7 @@ our @EXPORT_OK = qw(
                        check_symlink
                );
 
+our %SPEC;
 
 sub symlink_rel {
     my ($dest_path, $link_path) = @_;
@@ -87,6 +88,62 @@ sub adjust_rel_symlink {
     1;
 }
 
+$SPEC{check_symlink} = {
+    v => 1.1,
+    summary => "Perform various checks on a symlink",
+    args => {
+        symlink => {
+            summary => "Path to the symlink to be checked",
+            schema => "filename*",
+            req => 1,
+            pos => 0,
+        },
+        target => {
+            summary => "Expected target path",
+            schema => "filename*",
+            pos => 1,
+            description => <<'_',
+
+If specified, then target of symlink (after normalized to absolute path) will be
+checked and must point to this target.
+
+_
+        },
+        is_abs => {
+            summary => 'Whether we should check that symlink target is an absolute path',
+            schema => 'bool',
+            description => <<'_',
+
+If set to true, then symlink target must be an absolute path. If
+set to false, then symlink target must be a relative path.
+
+_
+        },
+        ext_matches => {
+            summary => 'Whether extension should match',
+            schema => 'bool',
+            description => <<'_',
+
+If set to true, then if both symlink name and target filename contain filename
+extension (e.g. `jpg`) then they must match. Case variation is allowed (e.g.
+`JPG`) but other variation is not (e.g. `jpeg`).
+
+_
+        },
+        content_matches => {
+            summary => 'Whether content should match extension',
+            schema => 'bool',
+            description => <<'_',
+
+If set to true, will guess media type from content and check that file extension
+exists nd matches the media type. Requires <pm:File::MimeInfo::Magic>, which is
+only specified as a "Recommends" dependency by File-Symlink-Util distribution.
+
+_
+        },
+    },
+};
+
 sub check_symlink {
     my %args = @_;
     my $res = [200, "OK", []];
@@ -172,7 +229,7 @@ File::Symlink::Util - Utilities related to symbolic links
 
 =head1 VERSION
 
-This document describes version 0.002 of File::Symlink::Util (from Perl distribution File-Symlink-Util), released on 2023-06-30.
+This document describes version 0.003 of File::Symlink::Util (from Perl distribution File-Symlink-Util), released on 2023-06-30.
 
 =head1 SYNOPSIS
 
@@ -240,51 +297,69 @@ to point to the original target. See example in Synopsis for illustration.
 
 Both C<$link_path1> and C<$link_path2> must be symlink.
 
+
 =head2 check_symlink
 
 Usage:
 
- my $res = check_symlink(%args);
+ check_symlink(%args) -> [$status_code, $reason, $payload, \%result_meta]
 
-Perform various checks on a symlink. Will return an <enveloped
-result|Rinci::function/"Enveloped result">, an array of the following structure:
-C<< [$code, $message, $content] >>. C<$status> will be 200 if symlink passes all
-checks. Otherwise, status will be 500 with C<$content> containing an arrayref of
-error messages.
+Perform various checks on a symlink.
 
-Arguments:
+This function is not exported by default, but exportable.
 
-=over
+Arguments ('*' denotes required arguments):
 
-=item * symlink
+=over 4
 
-Str, required. Path to the symlink.
+=item * B<content_matches> => I<bool>
 
-=item * target
+Whether content should match extension.
 
-Str, optional. If specified, then target of symlink (after normalized to
-absolute path) will be checked and must point to this target.
+If set to true, will guess media type from content and check that file extension
+exists nd matches the media type. Requires L<File::MimeInfo::Magic>, which is
+only specified as a "Recommends" dependency by File-Symlink-Util distribution.
 
-=item * is_abs
+=item * B<ext_matches> => I<bool>
 
-Bool, optional. If set to true, then symlink target must be an absolute path. If
+Whether extension should match.
+
+If set to true, then if both symlink name and target filename contain filename
+extension (e.g. C<jpg>) then they must match. Case variation is allowed (e.g.
+C<JPG>) but other variation is not (e.g. C<jpeg>).
+
+=item * B<is_abs> => I<bool>
+
+Whether we should check that symlink target is an absolute path.
+
+If set to true, then symlink target must be an absolute path. If
 set to false, then symlink target must be a relative path.
 
-=item * ext_matches
+=item * B<symlink>* => I<filename>
 
-Bool, optional. If set to true, then if both symlink name and target filename
-contain filename extension (e.g. C<.jpg>) then they must match. Case variation
-is allowed (e.g. C<JPG>) but other variation is not (e.g. C<jpeg>).
+Path to the symlink to be checked.
 
-=item * content_matches
+=item * B<target> => I<filename>
+
+Expected target path.
+
+If specified, then target of symlink (after normalized to absolute path) will be
+checked and must point to this target.
 
-Bool, optional. If set to true, will guess media type from content and check
-that file extension exists nd matches the media type. Requires
-L<File::MimeInfo::Magic>, which is only specified as a "Recommends" dependency
-by File-Symlink-Util distribution.
 
 =back
 
+Returns an enveloped result (an array).
+
+First element ($status_code) is an integer containing HTTP-like status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
+
+Return value:  (any)
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/File-Symlink-Util>.
